@@ -1,6 +1,3 @@
-#!/usr/bin/env python
-# coding: utf-8
-#
 # This file is part of Supysonic.
 # Supysonic is a Python implementation of the Subsonic server API.
 #
@@ -9,6 +6,8 @@
 #
 # Distributed under terms of the GNU AGPLv3 license.
 
+import unittest
+
 from .apitestbase import ApiTestBase
 
 
